pub struct ClientKeysPaths {
pub private_identity_key_file: PathBuf,
pub public_identity_key_file: PathBuf,
pub private_encryption_key_file: PathBuf,
pub public_encryption_key_file: PathBuf,
pub ack_key_file: PathBuf,
}Fields
private_identity_key_file: PathBufPath to file containing private identity key.
public_identity_key_file: PathBufPath to file containing public identity key.
private_encryption_key_file: PathBufPath to file containing private encryption key.
public_encryption_key_file: PathBufPath to file containing public encryption key.
ack_key_file: PathBufPath to file containing key used for encrypting and decrypting the content of an acknowledgement so that nobody besides the client knows which packet it refers to.
Implementations
Sourceimpl ClientKeysPaths
impl ClientKeysPaths
pub fn new_base<P>(base_data_directory: P) -> ClientKeysPaths
pub fn identity_key_pair_path(&self) -> KeyPairPath
pub fn encryption_key_pair_path(&self) -> KeyPairPath
pub fn any_file_exists(&self) -> bool
pub fn any_file_exists_and_return(&self) -> Option<PathBuf>
pub fn private_identity_key(&self) -> &Path
pub fn public_identity_key(&self) -> &Path
pub fn private_encryption_key(&self) -> &Path
pub fn public_encryption_key(&self) -> &Path
pub fn ack_key(&self) -> &Path