pub struct CommonClientPaths {
pub keys: ClientKeysPaths,
pub gateway_registrations: PathBuf,
pub credentials_database: PathBuf,
pub reply_surb_database: PathBuf,
}Fields
keys: ClientKeysPathsgateway_registrations: PathBufPath to the file containing information about gateways used by this client, i.e. details such as their public keys, owner addresses or the network information.
credentials_database: PathBufPath to the database containing bandwidth credentials of this client.
reply_surb_database: PathBufPath to the persistent store for received reply surbs, unused encryption keys and used sender tags.
Implementations
Sourceimpl CommonClientPaths
impl CommonClientPaths
pub fn new_base<P>(base_data_directory: P) -> CommonClientPaths