pub struct DebugConfigV4 {
pub traffic: TrafficV4,
pub cover_traffic: CoverTrafficV4,
pub gateway_connection: GatewayConnectionV4,
pub acknowledgements: AcknowledgementsV4,
pub topology: TopologyV4,
pub reply_surbs: ReplySurbsV4,
}Fields
traffic: TrafficV4Defines all configuration options related to traffic streams.
cover_traffic: CoverTrafficV4Defines all configuration options related to cover traffic stream(s).
gateway_connection: GatewayConnectionV4Defines all configuration options related to the gateway connection.
acknowledgements: AcknowledgementsV4Defines all configuration options related to acknowledgements, such as delays or wait timeouts.
topology: TopologyV4Defines all configuration options related topology, such as refresh rates or timeouts.
reply_surbs: ReplySurbsV4Defines all configuration options related to reply SURBs.