pub struct DebugConfigV6 {
pub traffic: TrafficV6,
pub cover_traffic: CoverTrafficV6,
pub gateway_connection: GatewayConnectionV6,
pub acknowledgements: AcknowledgementsV6,
pub topology: TopologyV6,
pub reply_surbs: ReplySurbsV6,
pub stats_reporting: StatsReportingV6,
pub forget_me: ForgetMeV6,
pub remember_me: RememberMeV6,
}Fields
traffic: TrafficV6Defines all configuration options related to traffic streams.
cover_traffic: CoverTrafficV6Defines all configuration options related to cover traffic stream(s).
gateway_connection: GatewayConnectionV6Defines all configuration options related to the gateway connection.
acknowledgements: AcknowledgementsV6Defines all configuration options related to acknowledgements, such as delays or wait timeouts.
topology: TopologyV6Defines all configuration options related topology, such as refresh rates or timeouts.
reply_surbs: ReplySurbsV6Defines all configuration options related to reply SURBs.
stats_reporting: StatsReportingV6Defines all configuration options related to stats reporting.
forget_me: ForgetMeV6Defines all configuration options related to the forget me flag.
remember_me: RememberMeV6Defines all configuration options related to the remember me flag.