pub struct Acknowledgements {
pub average_ack_delay: Duration,
pub ack_wait_multiplier: f64,
pub ack_wait_addition: Duration,
}Fields
average_ack_delay: DurationThe parameter of Poisson distribution determining how long, on average, sent acknowledgement is going to be delayed at any given mix node. So for an ack going through three mix nodes, on average, it will take three times this value until the packet reaches its destination.
ack_wait_multiplier: f64Value multiplied with the expected round trip time of an acknowledgement packet before it is assumed it was lost and retransmission of the data packet happens. In an ideal network with 0 latency, this value would have been 1.
ack_wait_addition: DurationValue added to the expected round trip time of an acknowledgement packet before it is assumed it was lost and retransmission of the data packet happens. In an ideal network with 0 latency, this value would have been 0.