pub struct Client {
pub version: String,
pub id: String,
pub disabled_credentials_mode: bool,
pub nyxd_urls: Vec<Url>,
pub nym_api_urls: Vec<Url>,
}Fields
version: StringVersion of the client for which this configuration was created.
id: StringID specifies the human readable ID of this particular client.
disabled_credentials_mode: boolIndicates whether this client is running in a disabled credentials mode, thus attempting to claim bandwidth without presenting bandwidth credentials.
nyxd_urls: Vec<Url>Addresses to nyxd validators via which the client can communicate with the chain.
nym_api_urls: Vec<Url>Addresses to APIs running on validator from which the client gets the view of the network.
Implementations