pub struct CoverTraffic {
pub loop_cover_traffic_average_delay: Duration,
pub cover_traffic_primary_size_ratio: f64,
pub disable_loop_cover_traffic_stream: bool,
}Fields
loop_cover_traffic_average_delay: DurationThe parameter of Poisson distribution determining how long, on average, it is going to take for another loop cover traffic message to be sent.
cover_traffic_primary_size_ratio: f64Specifies the ratio of primary_packet_size to secondary_packet_size used in cover traffic.
Only applicable if secondary_packet_size is enabled.
disable_loop_cover_traffic_stream: boolControls whether the dedicated loop cover traffic stream should be enabled. (and sending packets, on average, every Self::loop_cover_traffic_average_delay)