pub struct GatewayConnection {
pub gateway_response_timeout: Duration,
}Fields
gateway_response_timeout: DurationHow long we’re willing to wait for a response to a message sent to the gateway, before giving up on it.