pub struct ReplySurbs {
pub minimum_reply_surb_storage_threshold: usize,
pub maximum_reply_surb_storage_threshold: usize,
pub minimum_reply_surb_threshold_buffer: usize,
pub minimum_reply_surb_request_size: u32,
pub maximum_reply_surb_request_size: u32,
pub maximum_allowed_reply_surb_request_size: u32,
pub maximum_reply_surb_rerequest_waiting_period: Duration,
pub maximum_reply_surb_drop_waiting_period: Duration,
pub maximum_reply_surbs_rerequests: usize,
pub maximum_reply_key_age: Duration,
pub surb_mix_hops: Option<u8>,
}Fields
minimum_reply_surb_storage_threshold: usizeDefines the minimum number of reply surbs the client wants to keep in its storage at all times. It can only allow to go below that value if its to request additional reply surbs.
maximum_reply_surb_storage_threshold: usizeDefines the maximum number of reply surbs the client wants to keep in its storage at any times.
minimum_reply_surb_threshold_buffer: usizeDefines the soft threshold ontop of the minimum reply surb storage threshold for when the client should proactively request additional reply surbs.
minimum_reply_surb_request_size: u32Defines the minimum number of reply surbs the client would request.
maximum_reply_surb_request_size: u32Defines the maximum number of reply surbs the client would request.
maximum_allowed_reply_surb_request_size: u32Defines the maximum number of reply surbs a remote party is allowed to request from this client at once.
maximum_reply_surb_rerequest_waiting_period: DurationDefines maximum amount of time the client is going to wait for reply surbs before explicitly asking for more even though in theory they wouldn’t need to.
maximum_reply_surb_drop_waiting_period: DurationDefines maximum amount of time the client is going to wait for reply surbs before deciding it’s never going to get them and would drop all pending messages
maximum_reply_surbs_rerequests: usizeDefines maximum number of times the client is going to re-request reply surbs for clearing pending messages before giving up after making no progress.
maximum_reply_key_age: DurationDefines maximum amount of time given reply key is going to be valid for. This is going to be superseded by key rotation once implemented.
surb_mix_hops: Option<u8>Specifies the number of mixnet hops the packet should go through. If not specified, then the default value is used.