Traffic

Struct Traffic 

pub struct Traffic {
    pub average_packet_delay: Duration,
    pub message_sending_average_delay: Duration,
    pub disable_main_poisson_packet_distribution: bool,
    pub deterministic_route_selection: bool,
    pub maximum_number_of_retransmissions: Option<u32>,
    pub primary_packet_size: PacketSize,
    pub secondary_packet_size: Option<PacketSize>,
    pub use_legacy_sphinx_format: bool,
    pub packet_type: PacketType,
    pub disable_mix_hops: bool,
}

Fields

average_packet_delay: Duration

The parameter of Poisson distribution determining how long, on average, sent packet is going to be delayed at any given mix node. So for a packet going through three mix nodes, on average, it will take three times this value until the packet reaches its destination.

message_sending_average_delay: Duration

The parameter of Poisson distribution determining how long, on average, it is going to take another ‘real traffic stream’ message to be sent. If no real packets are available and cover traffic is enabled, a loop cover message is sent instead in order to preserve the rate.

disable_main_poisson_packet_distribution: bool

Controls whether the main packet stream constantly produces packets according to the predefined poisson distribution.

deterministic_route_selection: bool

Specify whether route selection should be determined by the packet header.

maximum_number_of_retransmissions: Option<u32>

Specify how many times particular packet can be retransmitted None - no limit

primary_packet_size: PacketSize

Specifies the packet size used for sent messages. Do not override it unless you understand the consequences of that change.

secondary_packet_size: Option<PacketSize>

Specifies the optional auxiliary packet size for optimizing message streams. Note that its use decreases overall anonymity. Do not set it unless you understand the consequences of that change.

use_legacy_sphinx_format: bool

Specify whether any constructed sphinx packets should use the legacy format, where the payload keys are explicitly attached rather than using the seeds this affects any forward packets, acks and reply surbs this flag should remain disabled until sufficient number of nodes on the network has upgraded and support updated format. in the case of reply surbs, the recipient must also understand the new encoding

packet_type: PacketTypedisable_mix_hops: bool

Indicates whether to mix hops or not. If mix hops are enabled, traffic will be routed as usual, to the entry gateway, through three mix nodes, egressing through the exit gateway. If mix hops are disabled, traffic will be routed directly from the entry gateway to the exit gateway, bypassing the mix nodes.

This overrides the use_legacy_sphinx_format setting as reduced mix hops requires use of the updated SURB packet format.

Implementations

Source

impl Traffic

pub fn validate(&self) -> bool