pub struct NymRouteProvider {
pub topology: NymTopology,
pub ignore_egress_epoch_roles: bool,
}Fields
topology: NymTopologyignore_egress_epoch_roles: boolAllow constructing routes with final hop at nodes that are not entry/exit gateways in the current epoch
Implementations
Sourceimpl NymRouteProvider
impl NymRouteProvider
pub fn new( topology: NymTopology, ignore_egress_epoch_roles: bool, ) -> NymRouteProvider
pub fn current_key_rotation(&self) -> u32
pub fn absolute_epoch_id(&self) -> u32
pub fn metadata(&self) -> NymTopologyMetadata
pub fn new_empty(ignore_egress_epoch_roles: bool) -> NymRouteProvider
pub fn update(&mut self, new_topology: NymTopology)
pub fn clear_topology(&mut self)
pub fn with_ignore_egress_epoch_roles( self, ignore_egress_epoch_roles: bool, ) -> NymRouteProvider
pub fn ignore_egress_epoch_roles(&mut self, ignore_egress_epoch_roles: bool)
pub fn egress_by_identity( &self, node_identity: PublicKey, ) -> Result<&RoutingNode, NymTopologyError>
pub fn node_by_identity(&self, node_identity: PublicKey) -> Option<&RoutingNode>
Sourcepub fn random_route_to_egress<R>(
&self,
rng: &mut R,
egress_identity: PublicKey,
) -> Result<Vec<Node>, NymTopologyError>
pub fn random_route_to_egress<R>( &self, rng: &mut R, egress_identity: PublicKey, ) -> Result<Vec<Node>, NymTopologyError>
Tries to create a route to the egress point, such that it goes through mixnode on layer 1, mixnode on layer2, …. mixnode on layer n and finally the target egress, which can be any known node
Sourcepub fn empty_route_to_egress(
&self,
egress_identity: PublicKey,
) -> Result<Vec<Node>, NymTopologyError>
pub fn empty_route_to_egress( &self, egress_identity: PublicKey, ) -> Result<Vec<Node>, NymTopologyError>
Returns a route directly to the egress point, which can be any known node
pub fn random_path_to_egress<R>( &self, rng: &mut R, egress_identity: PublicKey, ) -> Result<(Vec<&RoutingNode>, &RoutingNode), NymTopologyError>